@@ -95,6 +95,8 @@ class TextFormatter(BaseFormatter):
             # replace common typing errors
             if c == "’":
                 c = "'"
+            elif c == "–":
+                c = "-"
 
             if c == "%" or c == "&":
                 is_valid = True
@@ -134,6 +136,8 @@ class TextFormatter(BaseFormatter):
 
             if is_valid:
                 c_list.append(c)
+            else:
+                c_list.append(" ")  # adding a space, it will be trimmed later on
 
         text = "".join(c_list)
 
@@ -141,105 +145,103 @@ class TextFormatter(BaseFormatter):
         change_list = {}
         text_iter = text.split()
         for idx, word in enumerate(text_iter):
-            if word:
-                # replace number with words
-                to_append = None
+            if not word:
+                continue
 
-                # keep word as it will be in the change list
-                if (
-                    len(word) == 4
-                    and word.isdigit()
-                    and (
-                        int(word) < 2100
-                        and int(word) > 1700
-                        or idx > 0
-                        and text_iter[idx - 1].lower()
-                        in YEAR_PRECEEDING_WORDS[self.lang]
-                    )
-                ):
-                    # this needs further improvements
-                    # in (year) 1900
-                    # match year before matching numbers
-                    # this is a best-guess approach
-                    to_append = self.n2w(word, to="year")
-                elif re.match(r"^[\d,]+$", word):  # number or number with comma
-                    to_append = self.n2w(word)
-                elif re.match(
-                    r"^[+]*[(]{0,1}[0-9]{1,4}[)]{0,1}[-\s\./0-9]*$", word
-                ):  # complete telephone number regex, although it will only be like 123-123-123
-                    to_append = []
-                    for digit in re.sub("[^0-9]", "", word):
-                        to_append += self.n2w(digit)
-                elif "%" in word:
-                    newword = word.replace("%", "")
-                    if newword.isdigit():
-                        to_append = self.n2w(newword) + [PERCENT_WORD.get(self.lang)]
-                    else:
-                        newword = self.remove_invalid_chars(newword)
-                        to_append = [newword, PERCENT_WORD.get(self.lang)]
-                elif "&" in word:
-                    newword = word.replace("&", f" {AND_WORD.get(self.lang)} ")
-                    to_append = newword.strip().split()
-                elif "-" in word:
-                    newword = word.replace("-", " ")
-                    to_append = newword.split()
-                elif ":" in word:
-                    newword = word.replace(":", " ")
-                    to_append = []
-                    for t in newword.split():
-                        to_append += self.n2w(t)
-                elif (
-                    self.lang == "en"
-                    and len(word) > 2
-                    and word[:-2].isdigit()
-                    and word[-2:].lower() in ["th", "st", "rd", "nd"]
-                ):
-                    # 125th
-                    # TODO this is English only
-                    to_append = self.n2w(word[:-2], to="ordinal")
-                elif len(word) == 5 and word[:4].isdigit() and word[-1].lower() == "s":
-                    # 1900s
-                    to_append = self.n2w(word[:4], to="year")
-                elif (
-                    len(word) > 2 and word[:-2].isdigit() and word[-2:].lower() == "'s"
-                ):
-                    # 80's
-                    to_append = self.n2w(word[:-2])
-                    to_append.append(word[-2:])
-                elif self.is_currency(word):
-                    name, value = self.is_currency(word)
-                    to_append = self.n2w(value)
-                    to_append.append(name)
-                elif len(word) > 1 and re.match(
-                    r"^M{0,4}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})$", word
-                ):
-                    # "I" will be One, but it is wrong. We prefer "I" to roman "One"
-                    # same applies for German, that M is probably a letter
-                    # it applis to all single X, M, I, etc.
-                    to_append = self.roman2w(word)
+            to_append = None
+
+            # keep word as it will be in the change list
+            if (
+                len(word) == 4
+                and word.isdigit()
+                and (
+                    int(word) < 2100
+                    and int(word) > 1700
+                    or idx > 0
+                    and text_iter[idx - 1].lower() in YEAR_PRECEEDING_WORDS[self.lang]
+                )
+            ):
+                # this needs further improvements
+                # in (year) 1900
+                # match year before matching numbers
+                # this is a best-guess approach
+                to_append = self.n2w(word, to="year")
+            elif re.match(r"^[\d,]+$", word):  # number or number with comma
+                to_append = self.n2w(word)
+            elif re.match(
+                r"^[+]*[(]{0,1}[0-9]{1,4}[)]{0,1}[-\s\./0-9]*$", word
+            ):  # complete telephone number regex, although it will only be like 123-123-123
+                to_append = []
+                for digit in re.sub("[^0-9]", "", word):
+                    to_append += self.n2w(digit)
+            elif "%" in word:
+                newword = word.replace("%", "")
+                if newword.isdigit():
+                    to_append = self.n2w(newword) + [PERCENT_WORD.get(self.lang)]
+                else:
+                    newword = self.remove_invalid_chars(newword)
+                    to_append = [newword, PERCENT_WORD.get(self.lang)]
+            elif "&" in word:
+                newword = word.replace("&", f" {AND_WORD.get(self.lang)} ")
+                to_append = newword.strip().split()
+            elif "-" in word:
+                newword = word.replace("-", " ")
+                to_append = newword.split()
+            elif ":" in word:
+                newword = word.replace(":", " ")
+                to_append = []
+                for t in newword.split():
+                    to_append += self.n2w(t)
+            elif (
+                self.lang == "en"
+                and len(word) > 2
+                and word[:-2].isdigit()
+                and word[-2:].lower() in ["th", "st", "rd", "nd"]
+            ):
+                # 125th
+                # TODO this is English only
+                to_append = self.n2w(word[:-2], to="ordinal")
+            elif len(word) == 5 and word[:4].isdigit() and word[-1].lower() == "s":
+                # 1900s
+                to_append = self.n2w(word[:4], to="year")
+            elif len(word) > 2 and word[:-2].isdigit() and word[-2:].lower() == "'s":
+                # 80's
+                to_append = self.n2w(word[:-2])
+                to_append.append(word[-2:])
+            elif self.is_currency(word):
+                name, value = self.is_currency(word)
+                to_append = self.n2w(value)
+                to_append.append(name)
+            elif len(word) > 1 and re.match(
+                r"^M{0,4}(CM|CD|D?C{0,3})(XC|XL|L?X{0,3})(IX|IV|V?I{0,3})$", word
+            ):
+                # "I" will be One, but it is wrong. We prefer "I" to roman "One"
+                # same applies for German, that M is probably a letter
+                # it applis to all single X, M, I, etc.
+                to_append = self.roman2w(word)
+            else:
+                m = re.match(
+                    r"^([a-zA-Z]+)(\d+)$", word
+                )  # particular case like "gate E25"
+                if m:
+                    if not m.group(1).lower().startswith("xx"):
+                        # such as XXEY1, phonics
+                        to_append = [m.group(1)] + self.n2w(m.group(2))
                 else:
                     m = re.match(
-                        r"^([a-zA-Z]+)(\d+)$", word
-                    )  # particular case like "gate E25"
+                        r"^(\d+)([a-zA-Z]+)$", word
+                    )  # particular case like "seat 12C"
                     if m:
-                        if not m.group(1).lower().startswith("xx"):
-                            # such as XXEY1, phonics
-                            to_append = [m.group(1)] + self.n2w(m.group(2))
-                    else:
-                        m = re.match(
-                            r"^(\d+)([a-zA-Z]+)$", word
-                        )  # particular case like "seat 12C"
-                        if m:
-                            to_append = self.n2w(m.group(1)) + [m.group(2)]
+                        to_append = self.n2w(m.group(1)) + [m.group(2)]
 
-                if to_append is None:
-                    to_append = [word]
-                else:
-                    change_list[word] = " ".join(
-                        [x.upper() if self.return_upper_case else x for x in to_append]
-                    )
+            if to_append is None:
+                to_append = [word]
+            else:
+                change_list[word] = " ".join(
+                    [x.upper() if self.return_upper_case else x for x in to_append]
+                )
 
-                word_list += to_append
+            word_list += to_append
 
         text = " ".join(word_list)
         if self.return_upper_case:
